function varargout = dpr1eigmulti(dpr1_data,r,tol)  
% Calls dpr1eig multiple times (r times) to compute eigenvalues of the
% whole system
%
% Return eigenvalues only:
%   L = dpr1eigmulti(dpr1_data,r,tol)
%
% Return eigenvectors and eigenvalues:
%   [X,L] = dpr1eigmulti(dpr1_data,r,tol)
%
% =========================================================================
% |  dpr1eigmulti.m                                                       |
% |  Copyright (C) 2020 Matea Ugrica                                      |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================
    
    % The data precomputed by transformEigensystem 
    n       = dpr1_data.n;
    D       = dpr1_data.D;
    u       = dpr1_data.u; 
    v       = dpr1_data.v; 
    BI      = dpr1_data.BI;
    T       = dpr1_data.T;
    O       = dpr1_data.O;
    n_var   = dpr1_data.n_var;
    
    % calling dpr1eig
    if size(v,2) == 1
        if nargout == 2
            % A = diag(D) - r * (u * v');
            [L, X] = dpr1eig(D, v, u, -r, tol);

            % Change of basis if eigenvectors needed
            for l = 1 : n
               d = 2 * l - 1 : 2 * l; 
               %e = 1 : 2 * n;
               X(d, :) = BI(:, d) * X(d, :); 
            end
            % Original eigenvecotrs
            X = (diag(1 ./ O) * X(1 : 2 : 2 * n, :));
            if tol.flag_smw_all
                X = inverseIterationSMW(L,X,O,T,dpr1_data,r);
            end
            X = normalizeColumns(T*X);
            varargout{1} = X;
            varargout{2} = L;
        else
            L = dpr1eig(D, v, u, -r, tol);
            varargout{1} = L;
        end
    else       
         if nargout == 2
            [L, X1] = dpr1eig(D, v(:,1), u(:,1), -r(1), tol);
            
            % Change of basis if eigenvectors needed
            X = zeros(2*n, 2*n);
            for l = 1 : n
               d = 2 * l - 1 : 2 * l; 
               X(d, :) = BI(:, d) * X1(d, :); 
            end
            for ii=2:n_var
                v(:,ii:n_var)=X1\v(:,ii:n_var);
                u(:,ii:n_var)=(u(:,ii:n_var)'*X1)';
                [L,X1] = dpr1eig(L, v(:,ii),u(:,ii), -r(ii), tol);
                X = X* X1; 
            end
            % Original eigenvectors
            X = (diag(1 ./ O) * X(1 : 2 : 2 * n, :));
            if tol.flag_smw_all
                X = inverseIterationSMW(L,X,O,T,dpr1_data,r);
            end
            X = normalizeColumns(T*X);
            varargout{1} = X;
            varargout{2} = L;
         else
            [L, X1] = dpr1eig(D, v(:,1), u(:,1), -r(1), tol);
            for ii=2:n_var-1
                v(:,ii:n_var)=X1\v(:,ii:n_var);
                u(:,ii:n_var)=(u(:,ii:n_var)'*X1)';
                [L,X1] = dpr1eig(L, v(:,ii),u(:,ii), -r(ii), tol);
            end
            L = dpr1eig(L, X1\v(:,n_var),(u(:,n_var)'*X1)', -r(n_var), tol);
            varargout{1} = L;
         end
    end
end

function X = normalizeColumns(X)
    k = size(X,2);
    for j = 1:k
        x       = X(:,j);
        X(:,j)  = x/norm(x);
    end
end

function X = inverseIterationSMW(L,X,O,T,dpr1_data,v)

    alpha   = dpr1_data.alpha;
    n_var   = dpr1_data.n_var;
    B       = dpr1_data.B;
    I       = eye(n_var);
    V       = B.'*T;
    Vtv     = V.'*diag(v);
    
    for l = 1:size(L)
        A           = O.^2 + L(l)^2 + L(l)*alpha*O;
        U           = L(l)*Vtv;
        AinvU       = U./A;
        I_VAinvU    = I + V*AinvU;
        xl          = X(:,l);
        Ainv_xl     = conj(xl)./A;
        x_new       = Ainv_xl - AinvU*(I_VAinvU\(V*Ainv_xl));
        if any(~isfinite(x_new))
            break
        else
            xl      = x_new;
        end
        X(:,l)      = xl;
    end 
end
