function dpr1_data = transformEigensystem(K,M,B,alpha)
% Perform the offline phase for dpr1eigmulti.
%
% =========================================================================
% |  transformEigensystem.m                                               |
% |  Copyright (C) 2020 Matea Ugrica                                      |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================

    n = length(K);
    
    % Transforming system into
    %   F(\lambda) = \lambda^2 I + \lambda (alpha O +rvv') + O^2
    [T,O2] = eig(K,M,'vector');
    O = sqrt(O2);

    % Linearization of the transformed system
    % We apply perfect shuffle to obtain blockdiagonal matrix.
    p = zeros(2 * n, 1);
    p(1 : 2 : end) = 1 : n;
    p(2 : 2 : end) = n + 1 : 2 * n;

    v = [zeros(n, size(B,2)); T' * B];
    v = v(p,:); % vector permutation
    u = v;
    % Diagonalization.
    D = zeros(2 * n, 1);
    BI = zeros(2, 2 * n); % Basis for diagonalization of A

    for l = 1 : n
        % diagonlization of 2x2 block
        d = 2 * l - 1 : 2 * l;
        Ol = O(l);
        [X, L] = eig([0, Ol; -Ol, -alpha*Ol]);
        u(d,:) = (u(d,:)'* X)';
        v(d,:) = X\ v(d,:);
        D(d) = diag(L);
        BI(:, d) = X;
    end
 
    % data for dpr1 code
    dpr1_data.n     = n;
    dpr1_data.D     = D;
    dpr1_data.u     = u;
    dpr1_data.v     = v;
    dpr1_data.alpha = alpha;
    dpr1_data.O     = O;
    dpr1_data.T     = T;
    dpr1_data.BI    = BI;
    dpr1_data.B     = B;
    dpr1_data.n_var = size(B,2);
end