function sys = getExample3(n,conf_idx,alpha)
% creating MCK examples
% INPUT:
% n        - dimension
% conf_idx - configuration of the external damping matrix
% alpha    - parameter for the internal damping matrix
% OUTPUT:
% matrices: M (mass), K (stiffness), C (internal damping), B (B*B' external damping) 
%
% =========================================================================
% |  getExample3.m                                                        |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================
  
    if nargin < 3
        alpha = 0.004;
    end

    K = 5*(2*eye(n)-diag(ones(n-1,1),1)-diag(ones(n-1,1),-1));
    for ii=1:n/2
        dm(ii)=n-ii/2;
    end
    M = diag([dm,dm(end:-1:1)])/100;
    C = alpha*sqrtm(M)*(sqrtm((sqrtm(M)\K)/sqrtm(M)))*sqrtm(M);
   
    m = n/10;
    % construct a rank 10 0.02 

    d               = 3;
    conf            = zeros(1,3);
    B               = zeros(n,d);

    tmp = 1;
    %creating different configurtions
    for ii = m : 2*m : n-m
        for jj = ii+m : 2*m : n-m
            for kk = jj+m : 2*m : n-m
                conf(tmp,:) = [ii, jj, kk];
                tmp       = tmp + 1;
            end
        end
    end


    B(conf(conf_idx,1),1)          = 1;
    B(conf(conf_idx,3),2)          = 1;
    B([conf(conf_idx,2),conf(conf_idx,2)+1],3)  = [1;-1];

    if rank(B) < size(B,2)
        error('B must have full column rank');
    end
     
    sys = makeSysStruct(M,C,K,B,alpha,conf_idx);
end
