function errs = eigMatch(D,Dp,varargin)
%
% =========================================================================
% |  eigMatch.m                                                           |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================

    n       = length(D);
    val_err = zeros(1,n);   % Store all eigenvalue relative differences
    
    for k = 1:n
        % Get the jth computed eigenpair
        d           = D(k);

        % Compute the distance to the closest eigenvalue in Dp and
        % then set that value in Dp to nan, so it won't be paired again
        [~,indx]    = min(abs(Dp - d));
        indx        = indx(1);
        dp          = Dp(indx);
        Dp(indx)    = nan;
          
        % For complex numbers, we need to measure the errors in the real
        % and imaginary parts separately, as these errors can be much large
        % than abs(d - dp)/abs(d) is.
        re_err      = getError(real(d),real(dp));
        % For eigenvalues very close to being real, don't measure error in
        % the imaginary part, since it can be misleading.  We assume
        % eigenvalues come in conjugate pairs.
        if max(abs([imag(d) imag(dp)])) <= 1e-14
            im_err  = 0;
        else
            im_err  = getError(imag(d),imag(dp));
        end
        val_err(k)  = max([ re_err im_err ]);
    end
    
    errs = getErrorStats(val_err,'Eigenvalue',varargin{:});
 
end

function err = getError(x,y)
    % compute relative error |x - y|/min(|x|,|y|)
    % But if x==y==0, do an absolute error
    err     = abs(x - y);
    denom   = min([ abs(x) abs(y) ]);
    if denom ~= 0
        err = err/denom;
    end
end