function makeScalingPlots(data,save_plots)
%
% =========================================================================
% |  makeScalingPlots.m                                                   |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================

    if nargin < 2 
        save_plots = false;
    end
   
    ymax = roundTo10(max([getMaxTime(data.s1) getMaxTime(data.s2)]));

    makePlots(data.s1,'A');
    if ~save_plots
        fprintf('Press any key to make next plots\n');
        pause
    end
    makePlots(data.s2,'B');
    
    function makePlots(s,name)
        fprintf('Config %s plots: ',name);
        h = plotScaling(s);
        if save_plots
            saveas(h,['scaling_' name],'epsc');
        else
            fprintf('press any key to zoom in ...');
            pause
        end
        ylim([0 ymax]);
        legend off
        if save_plots
            fprintf('saved.\n');
            saveas(h,['scaling_' name '_zoom'],'epsc');
        else
            fprintf('done.\n');
        end        
    end

end

function t = getMaxTime(s)
    s = s.times;
    t = max([s.dpr1_off; s.dpr1_on; s.eig_off; s.eig_on]);
end

function x = roundTo10(x)
    x = 10*ceil(x/10);
end