function h = plotEigErrors(data,method1,method2)
%
% =========================================================================
% |  plotEigErrors.m                                                      |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================

    pargs   = {'LineWidth',2,'MarkerSize',10};

    n       = data.n_vals; 
    evals   = data.evalues;
    
    z1      = evals.(method1);
    z2      = evals.(method2);
    
    res     = data.res_dpr1;
    
    % Suppress eigMatch's printing by providing third argument
    errFn   = @(z1,z2) eigMatch(z1,z2,true);
    
    
    
    errs    = cellfun(errFn,z1,z2,'UniformOutput',false);
    % Convert cell array of structs to a single struct array
    e1      = [errs{:}];
    
    res_max     = cellfun(@(x) max(x(:)),res,'UniformOutput',false);
    res_median  = cellfun(@(x) median(x(:)),res,'UniformOutput',false);
    
    c           = lines();
    blue        = {'Color',c(1,:)};
    red         = {'Color',c(2,:)};
    
    h = figure();
    hold on
    grid on
    plot(n,[e1.median],'o',blue{:},pargs{:});
    plot(n,[e1.max],'x',blue{:},pargs{:});
    plot(n,[res_median{:}],'square',red{:},pargs{:});
    plot(n,[res_max{:}],'+',red{:},pargs{:});
    set(gca,'YScale','log');
    ylim([1e-15 1e-0]);
    legend({'$\lambda$ error - Median','$\lambda$ error - Worst',...
            '$(\lambda,x)$ resid. - Median','$(\lambda,x)$ resid. - Worst'},...
            'location','northwest', 'interpreter', 'latex','FontSize',18);
    xlabel('System dimension $n$', 'interpreter', 'latex');
    ylabel('Relative error', 'interpreter', 'latex');
    
    axis square
    largerTicks();
    xlim([min(n) max(n)]);
    xticks(n);
    tightFigure();
    
end
