function h = plotSpecConfigs(data,no_legend)
%
% =========================================================================
% |  plotSpecConfigs.m                                                    |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================

    if nargin < 2
        no_legend = false;
    end

    colors  = winter(256);
    c1      = colors(130,:);
    c2      = colors(256,:);
    colors  = autumn(256);
    c3      = colors(140,:);
    
    [a,b,c]             = deal(data.a,data.b,data.eta + 1i*data.omegas);
    [z_none,z_x0,z_opt] = deal(data.z_none,data.z_x0,data.z_opt);
    
    h = figure();
    hold on
    
    % Plot spectrum of the system with no exteral damping and at x0
    h_none  = plotSpectrum(z_none,'.',[0 0 0],':');
    h_zx0   = plotSpectrum(z_x0,'.',c2,'.-');
    
    % Plot the ellipses and active eigenvalues
    % Ensure these vectors are all column vectors (needed for arrayfun)
    a = a(:);
    b = b(:);
    c = c(:);
    
    plotEllFn   = @(a,b,c) plotEllipse(a,b,c,c3);
    arrayfun(plotEllFn,a,b,c);
    arrayfun(plotEllFn,a,b,conj(c));
    
    h_zopt  = plotSpectrum(z_opt,'.',c1,'--');

    legend([h_none h_zx0 h_zopt],   ...
           {'$v_\mathrm{zero}$','$v_\mathrm{init}$','$v_\mathrm{opt}$'},...
           'Interpreter','Latex','FontSize',18,...
           'Location','SouthWest');
    axis square
    grid on
    ylim([0 1.2]); 
    xlim([-2.8e-3 8e-5]);    
    largerTicks();
    tightFigure();
    if no_legend 
        legend off
    end
end

function [h1,h2] = plotSpectrum(z,spec,color,mark)
    switch spec
        case '.'
            ms = 12.5;
        otherwise
            ms = 7;
    end
    % Plot eigenvalues z
    h1 = plot(complex(z),spec,'Color',color,'MarkerSize',ms,'LineWidth',2);
    % Plot spectral abscissa line
    h2 = plot(max(real(z))*[1 1],ylim(),mark,'Color',color,'LineWidth',1.5);
end

function plotEllipse(a,b,c,color)
    t = linspace(0,2*pi,1000);
    x = a*cos(t)+real(c);
    y = b*sin(t)+imag(c);
    plot(x,y,'-','Color',color,'LineWidth',1.5); 
end