function data = runOptEx(approach,alpha,tol_sa)
%
% =========================================================================
% |  runOptEx.m                                                           |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================
    
    if nargin < 2
        alpha   = 0.001;
    end
    if nargin < 3
        tol_sa  = [];
    end

    % Example parameters
    n           = 1000;
    conf_idx    = 7;
    sys         = getExample3(n,conf_idx,alpha);
    
    % Model parameters
    use_dpr1    = true;
    eta         = 0;
    switch approach
        case 0  % Min spectral abscissa, no constraints
            a       = [];
            b       = [];
            omegas  = [];
            phis    = [];
        case 1  % Approach 1, min spectral abscissa, ellipse constraints
            a       = 1e-3;
            b       = 0.2;
            omegas  = 0.95;
            phis    = [];
        case 2  % Approach 2, max ellipses, spectral abscissa constraint
            a       = [];
            b       = [0.05,0.05,0.05];
            omegas  = [0.1 0.6 1.1];
            phis    = [1,0.2,0.1];
    end
    
    data        = optViscosities(sys,use_dpr1,tol_sa,a,b,omegas,eta,phis);
    printSummary(data);
    
end
